==> ideaIC-163.13906.16-sources.jar: com/intellij/codeInsight/editorActions/wordSelection/BasicSelectioner.java <==
/*
 * Copyright 2000-2009 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.codeInsight.editorActions.wordSelection;

import com.intellij.psi.*;
import com.intellij.psi.javadoc.PsiDocTag;
import com.intellij.psi.xml.XmlToken;
import com.intellij.psi.xml.XmlElement;
import com.intellij.codeInsight.editorActions.ExtendWordSelectionHandlerBase;

public class BasicSelectioner extends ExtendWordSelectionHandlerBase {

  @Override
  public boolean canSelect(PsiElement e) {
    return canSelectBasic(e);
  }

  public static boolean canSelectBasic(final PsiElement e) {
    return
      !(e instanceof PsiWhiteSpace) &&
      !(e instanceof PsiComment) &&
      !(e instanceof PsiCodeBlock) &&
      !(e instanceof PsiArrayInitializerExpression) &&
      !(e instanceof PsiParameterList) &&
      !(e instanceof PsiExpressionList) &&
      !(e instanceof PsiBlockStatement) &&
      !(e instanceof PsiJavaCodeReferenceElement) &&
      !(e instanceof PsiJavaToken &&
      !(e instanceof PsiKeyword)) &&
      !(e instanceof XmlToken) &&
      !(e instanceof XmlElement) &&
      !(e instanceof PsiDocTag);
  }
}

==> ideaIC-182.3208.16-sources.jar: com/intellij/codeInsight/editorActions/wordSelection/BasicSelectioner.java <==
/*
 * Copyright 2000-2009 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.codeInsight.editorActions.wordSelection;

import com.intellij.psi.*;
import com.intellij.psi.javadoc.PsiDocTag;
import com.intellij.psi.xml.XmlToken;
import com.intellij.psi.xml.XmlElement;
import com.intellij.codeInsight.editorActions.ExtendWordSelectionHandlerBase;
import org.jetbrains.annotations.NotNull;

public class BasicSelectioner extends ExtendWordSelectionHandlerBase {

  @Override
  public boolean canSelect(@NotNull PsiElement e) {
    return canSelectBasic(e);
  }

  public static boolean canSelectBasic(final PsiElement e) {
    return
      !(e instanceof PsiWhiteSpace) &&
      !(e instanceof PsiComment) &&
      !(e instanceof PsiCodeBlock) &&
      !(e instanceof PsiArrayInitializerExpression) &&
      !(e instanceof PsiParameterList) &&
      !(e instanceof PsiExpressionList) &&
      !(e instanceof PsiBlockStatement) &&
      !(e instanceof PsiJavaCodeReferenceElement) &&
      !(e instanceof PsiJavaToken &&
      !(e instanceof PsiKeyword)) &&
      !(e instanceof XmlToken) &&
      !(e instanceof XmlElement) &&
      !(e instanceof PsiDocTag);
  }
}
